local addonName, addon = ...

addon.frame = CreateFrame('FRAME')

--[[ Frame events ]] --

addon.frame:RegisterEvent('ADDON_LOADED')
addon.frame:RegisterEvent('COMBAT_LOG_EVENT_UNFILTERED')

addon.frame:SetScript('OnEvent', function(self, event, arg1)
    if (event == 'ADDON_LOADED' and arg1 == addonName) then
        self:Init()
    elseif (event == 'COMBAT_LOG_EVENT_UNFILTERED') then
        self:OnCombatLogEventUnfiltered(CombatLogGetCurrentEventInfo())
    end
end)

addon.frame:SetScript('OnEnter', function(self)
    self.tooltip = true
    self:SetTooltip()
end)

addon.frame:SetScript('OnLeave', function(self)
    self.tooltip = false
    self:RemTooltip()
end)

--[[ Frame functions ]] --

function addon.frame:Init()
    self.tooltip = false

    self:SetPoint('BOTTOMLEFT', 10, 10)
    self:SetSize(33, 33)

    self:SetFrameBackground()
    self:SetFrameOverlay()
    self:SetFrameCounter()

    addon:SetCounter()
end

function addon.frame:OnCombatLogEventUnfiltered(...)
    local timestamp, _, _, sourceGuid, _, sourceFlags, _, targetGuid, _, targetFlags = ...

    local isSourceHostile = bit.band(sourceFlags, COMBATLOG_OBJECT_REACTION_HOSTILE) > 0
    local isSourcePlayer = bit.band(sourceFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0

    if (isSourceHostile and isSourcePlayer) then addon:SetHostile(timestamp, sourceGuid) end

    local isTargetHostile = bit.band(targetFlags, COMBATLOG_OBJECT_REACTION_HOSTILE) > 0
    local isTargetPlayer = bit.band(targetFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0

    if (isTargetHostile and isTargetPlayer) then addon:SetHostile(timestamp, targetGuid) end
end

function addon.frame:SetFrameBackground()
    self.background = self:CreateTexture(nil, 'BACKGROUND')

    self.background:SetPoint('CENTER')
    self.background:SetSize(21, 21)
    self.background:SetTexture('Interface/Icons/Spell_Holy_ElunesGrace')
end

function addon.frame:SetFrameCounter()
    self.counter = self:CreateFontString(nil, 'ARTWORK', 'QuestFont_Shadow_Huge')

    self.counter:SetPoint('TOPLEFT', self, 'TOPRIGHT', 3, -6)
end

function addon.frame:SetFrameOverlay()
    self.overlay = self:CreateTexture(nil, 'OVERLAY')

    self.overlay:SetPoint('TOPLEFT')
    self.overlay:SetSize(56, 56)
    self.overlay:SetTexture('Interface/Minimap/MiniMap-TrackingBorder')
end

--[[ Tooltip functions ]] --

function addon.frame:GetTooltipNameRealmColor(timestamp)
    local difference = math.max(time() - timestamp, 0)
    local percentage = (difference / Radar.expiration)

    local base = UnitLevel('player') + 9
    local offset = math.floor(percentage * 20)

    return GetQuestDifficultyColor(base - offset)
end

function addon.frame:RemTooltip()
    GameTooltip:Hide()
end

function addon.frame:SetTooltip()
    if (not self.tooltip) then return end

    GameTooltip:Hide()

    GameTooltip:SetOwner(self, 'ANCHOR_NONE')
    GameTooltip:SetPoint('BOTTOMRIGHT', 'UIParent', 'BOTTOMRIGHT', -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y)
    GameTooltip:AddLine(GetAddOnInfo(addonName))

    for _, value in pairs(addon.hostiles) do
        local nameRealm = { value.name }
        local raceClass = { value.race, value.class }

        if (value.realm ~= '') then table.insert(nameRealm, value.realm) end

        local nameRealm = table.concat(nameRealm, '-')
        local nameRealmColor = self:GetTooltipNameRealmColor(value.timestamp)

        local raceClass = table.concat(raceClass, ' ')
        local raceClassColor = RAID_CLASS_COLORS[value.classSlug]

        GameTooltip:AddDoubleLine(nameRealm, raceClass,
            nameRealmColor.r, nameRealmColor.g, nameRealmColor.b,
            raceClassColor.r, raceClassColor.g, raceClassColor.b)
    end

    GameTooltip:Show()
end
