local addonName, addon = ...

addon.panel = CreateFrame('FRAME')

--[[ Panel events ]] --

addon.panel:RegisterEvent('ADDON_LOADED')

addon.panel:SetScript('OnEvent', function(self, event, arg1)
    if (event == 'ADDON_LOADED' and arg1 == addonName) then
        self:Init()
    end
end)

addon.panel:SetScript('OnShow', function(self)
    self.autohide:SetChecked(Radar.autohide)
    self.expiration:SetValue(Radar.expiration)
    self.warning:SetChecked(Radar.warning)
end)

--[[ Panel functions ]] --

function addon.panel:Init()
    Radar = Radar or self:GetDefaults()

    self.name = GetAddOnInfo(addonName)
    self.expiration_max = 300
    self.expiration_min = 5

    self:SetFrameTitle()
    self:SetFrameVersion()

    self:SetFrameAutohide()
    self:SetFrameWarning()
    self:SetFrameExpiration()

    self.cancel = function(this) this:OnInterfaceOptionsCancel() end
    self.default = function(this) this:OnInterfaceOptionsReset() end
    self.okay = function(this) this:OnInterfaceOptionsSubmit() end

    InterfaceOptions_AddCategory(self)
end

function addon.panel:GetDefaults()
    return { ['autohide'] = false, ['expiration'] = 90, ['warning'] = false }
end

function addon.panel:OnInterfaceOptionsCancel()
end

function addon.panel:OnInterfaceOptionsReset()
    Radar = self:GetDefaults()
end

function addon.panel:OnInterfaceOptionsSubmit()
    Radar.autohide = self.autohide:GetChecked()
    Radar.expiration = self.expiration:GetValue()
    Radar.warning = self.warning:GetChecked()

    addon:SetCounter()
end

function addon.panel:SetFrameAutohide()
    self.autohide = CreateFrame('CheckButton', nil, self, 'UICheckButtonTemplate')

    self.autohide:SetChecked(Radar.autohide)
    self.autohide:SetPoint('TOPLEFT', self, 'TOPLEFT', 10, -50)

    local label = addon:GetTranslation('Autohide counter')
    self.autohide.text:SetText(label)
end

function addon.panel:SetFrameExpiration()
    self.expiration = CreateFrame('Slider', nil, self, 'OptionsSliderTemplate')

    self.expiration:SetMinMaxValues(self.expiration_min, self.expiration_max)
    self.expiration:SetPoint('TOPRIGHT', self, 'TOPRIGHT', -20, -50)
    self.expiration:SetObeyStepOnDrag(true)
    self.expiration:SetValue(Radar.expiration)
    self.expiration:SetValueStep(1)
    self.expiration:SetWidth(200)

    self.expiration.High:SetText(self.expiration_max)
    self.expiration.Low:SetText(self.expiration_min)

    local label = addon:GetTranslation('Hostiles expire in {seconds} seconds', { ['seconds'] = Radar.expiration })
    self.expiration.Text:SetText(label)

    self.expiration:SetScript('OnValueChanged', function(this, value)
        local label = addon:GetTranslation('Hostiles expire in {seconds} seconds', { ['seconds'] = value })
        this.Text:SetText(label)
    end)
end

function addon.panel:SetFrameTitle()
    self.title = self:CreateFontString(nil, 'OVERLAY', 'GameFontNormalLarge')

    self.title:SetPoint('TOPLEFT', 15, -15)
    self.title:SetText(GetAddOnInfo(addonName))
end

function addon.panel:SetFrameVersion()
    self.version = self:CreateFontString(nil, 'OVERLAY', 'GameFontNormalSmall')

    self.version:SetTextColor(0.5, 0.5, 0.5)
    self.version:SetPoint('BOTTOMLEFT', self.title, 'BOTTOMRIGHT', 5, 1)
    self.version:SetText(GetAddOnMetadata(addonName, 'Version'))
end

function addon.panel:SetFrameWarning()
    self.warning = CreateFrame('CheckButton', nil, self, 'UICheckButtonTemplate')

    self.warning:SetChecked(Radar.warning)
    self.warning:SetPoint('TOPLEFT', self.autohide, 'BOTTOMLEFT', 0, 0)

    local label = addon:GetTranslation('Play warning sound')
    self.warning.text:SetText(label)
end
